@@ -7,19 +7,7 @@
  * By Gerald Combs <gerald@wireshark.org>
  * Copyright 1998 Gerald Combs
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License
- * as published by the Free Software Foundation; either version 2
- * of the License, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 #ifndef _PACKET_ISIS_CLV_H
@@ -48,8 +36,10 @@
 #define ISIS_CLV_AUTHENTICATION      10  /* iso10589, rfc3567 */
 #define ISIS_CLV_CHECKSUM            12  /* rfc3358 */
 #define ISIS_CLV_LSP_BUFFERSIZE      14  /* iso10589 rev2 */
+#define ISIS_CLV_REVERSE_METRIC      16  /* rfc8500 */
 #define ISIS_CLV_EXTD_IS_REACH       22  /* draft-ietf-isis-traffic-05 */
 #define ISIS_CLV_IS_ALIAS_ID         24  /* draft-ietf-isis-ext-lsp-frags-02 */
+#define ISIS_CLV_SRV6_LOCATOR        27  /* draft-bashandy-isis-srv6-extensions-04 */
 #define ISIS_CLV_INT_IP_REACH        128 /* rfc1195, rfc2966 */
 #define ISIS_CLV_PROTOCOLS_SUPPORTED 129 /* rfc1195 */
 #define ISIS_CLV_EXT_IP_REACH        130 /* rfc1195, rfc2966 */
@@ -60,15 +50,19 @@
 #define ISIS_CLV_EXTD_IP_REACH       135 /* draft-ietf-isis-traffic-05 */
 #define ISIS_CLV_HOSTNAME            137 /* rfc2763 */
 #define ISIS_CLV_SHARED_RISK_GROUP   138 /* rfc5307 */
+#define ISIS_CLV_IPV6_SRLG_TLV       139 /* rfc6119 */
+#define ISIS_CLV_IPV6_TE_ROUTER_ID   140 /* rfc6119 */
 #define ISIS_GRP_ADDR                142 /* rfc7176 */
 #define ISIS_CLV_MT_PORT_CAP         143 /* rfc6165, rfc7176 */
 #define ISIS_CLV_MT_CAP              144 /* rfc6329, rfc7176 */
 #define ISIS_CLV_TRILL_NEIGHBOR      145 /* rfc7176 */
+#define ISIS_CLV_BFD_ENABLED         148 /* rfc6213 */
 #define ISIS_CLV_SID_LABEL_BINDING   149 /* draft-previdi-isis-segment-routing-extensions-05 */
 #define ISIS_CLV_RESTART             211 /* draft-ietf-isis-restart-01 */
 #define ISIS_CLV_MT_IS_REACH         222 /* draft-ietf-isis-wg-multi-topology-05 */
 #define ISIS_CLV_MT_SUPPORTED        229 /* draft-ietf-isis-wg-multi-topology-05 */
 #define ISIS_CLV_IP6_ADDR            232 /* draft-ietf-isis-ipv6-02 */
+#define ISIS_CLV_IPV6_GBL_INT_ADDR   233 /* rfc6119 */
 #define ISIS_CLV_MT_IP_REACH         235 /* draft-ietf-isis-wg-multi-topology-05 */
 #define ISIS_CLV_IP6_REACH           236 /* draft-ietf-isis-ipv6-02 */
 #define ISIS_CLV_MT_IP6_REACH        237 /* draft-ietf-isis-wg-multi-topology-05 */
@@ -93,7 +87,7 @@ typedef struct {
  * are only valid from with isis decodes.
  */
 extern void isis_dissect_clvs(tvbuff_t *tvb, packet_info* pinfo, proto_tree *tree, int offset,
-        const isis_clv_handle_t *opts, expert_field* expert_short_len, int len, int id_length,
+        const isis_clv_handle_t *opts, expert_field* expert_short_len, guint len, int id_length,
         int unknown_tree_id,  int tree_type, int tree_length, expert_field ei_unknown);
 
 extern void isis_dissect_nlpid_clv(tvbuff_t *tvb, proto_tree *tree,
@@ -121,7 +115,7 @@ extern void isis_dissect_metric(tvbuff_t *tvb, proto_tree *tree, int offset,
 #endif /* _PACKET_ISIS_CLV_H */
 
 /*
- * Editor modelines  -  http://www.wireshark.org/tools/modelines.html
+ * Editor modelines  -  https://www.wireshark.org/tools/modelines.html
  *
  * Local variables:
  * c-basic-offset: 4
